@@ -15,13 +15,7 @@ from .doc_transcriber import (
 from .transcribed_document import TranscribedDocument
 
 if modules_are_available(["torchaudio", "transformers"]):
-    # fmt: off
-    from .hf_transcriber_function import HFTranscriberFunction  # noqa: F401
-    __all__.append("HFTranscriberFunction")
-    # fmt: on
+    __all__.append("hf_transcriber_function")
 
 if modules_are_available(["torch", "speechbrain"]):
-    # fmt: off
-    from .sb_transcriber_function import SBTranscriberFunction  # noqa: F401
-    __all__.append("SBTranscriberFunction")
-    # fmt: on
+    __all__.append("sb_transcriber_function")
