@@ -1,6 +1,10 @@
 __all__ = [
     "BratInputConverter",
     "BratOutputConverter",
+    "DoccanoInputConverter",
+    "DoccanoClientConfig",
+    "DoccanoOutputConverter",
+    "DoccanoTask",
     "medkit_json",
     "RTTMInputConverter",
     "RTTMOutputConverter",
@@ -9,12 +13,14 @@ __all__ = [
 from medkit.core.utils import modules_are_available
 
 from .brat import BratInputConverter, BratOutputConverter
+from .doccano import (
+    DoccanoInputConverter,
+    DoccanoTask,
+    DoccanoClientConfig,
+    DoccanoOutputConverter,
+)
 from . import medkit_json
 from .rttm import RTTMInputConverter, RTTMOutputConverter
 
 if modules_are_available(["spacy"]):
-    # fmt: off
-    from .spacy import SpacyInputConverter, SpacyOutputConverter  # noqa: F401
-    __all__.append("SpacyInputConverter")
-    __all__.append("SpacyOutputConverter")
-    # fmt: on
+    __all__.append("spacy")
