@@ -30,8 +30,11 @@ from medkit.core.text import (
     Span,
     TextDocument,
     span_utils,
+    utils,
 )
 
+from medkit.io._common import get_anns_by_type
+
 
 TEXT_EXT = ".txt"
 ANN_EXT = ".ann"
@@ -220,7 +223,13 @@ class BratInputConverter(InputConverter):
 
 class BratOutputConverter(OutputConverter):
     """Class in charge of converting a list of TextDocuments into a
-    brat collection file"""
+    brat collection file.
+
+    .. hint::
+        BRAT checks the coherence between span and text for each annotation.
+        This converter adjusts the text and spans to get the right visualization
+        and ensure compatibility.
+    """
 
     def __init__(
         self,
@@ -315,9 +324,20 @@ class BratOutputConverter(OutputConverter):
             doc_id = medkit_doc.uid if doc_names is None else doc_names[i]
 
             # convert medkit anns to brat format
-            segments, relations = self._get_anns_from_medkit_doc(medkit_doc)
+            annotations = get_anns_by_type(medkit_doc, anns_labels=self.anns_labels)
+            all_segments = annotations["entities"]
+
+            if not self.ignore_segments:
+                # In brat only entities exists, in some cases
+                # a medkit document could include segments
+                # that may be exported as entities
+                all_segments += annotations["segments"]
+
             brat_anns = self._convert_medkit_anns_to_brat(
-                segments, relations, config, text
+                segments=all_segments,
+                relations=annotations["relations"],
+                config=config,
+                raw_text=text,
             )
 
             # save text file
@@ -333,43 +353,6 @@ class BratOutputConverter(OutputConverter):
             conf_path = dir_path / ANN_CONF_FILE
             conf_path.write_text(config.to_str(), encoding="utf-8")
 
-    def _get_anns_from_medkit_doc(
-        self, medkit_doc: TextDocument
-    ) -> Tuple[List[Segment], List[Relation]]:
-        """Return selected annotations from a medkit document"""
-        if self.anns_labels is not None:
-            # filter annotations by label
-            annotations = [
-                ann
-                for label in self.anns_labels
-                for ann in medkit_doc.anns.get(label=label)
-            ]
-        else:
-            annotations = medkit_doc.anns.get()
-
-        if self.anns_labels and annotations == []:
-            # labels_anns were a list but none of the annotations
-            # had a label of interest
-            labels_str = ",".join(self.anns_labels)
-            logger.info(
-                "No medkit annotations were included because none have"
-                f" '{labels_str}' as label."
-            )
-
-        segments = []
-        relations = []
-        for ann in annotations:
-            if isinstance(ann, Entity):
-                segments.append(ann)
-            elif isinstance(ann, Segment) and not self.ignore_segments:
-                # In brat only entities exists, in some cases
-                # a medkit document could include segments
-                # that may be exported as entities
-                segments.append(ann)
-            elif isinstance(ann, Relation):
-                relations.append(ann)
-        return segments, relations
-
     def _convert_medkit_anns_to_brat(
         self,
         segments: List[Segment],
@@ -418,7 +401,7 @@ class BratOutputConverter(OutputConverter):
                     for a in medkit_segment.attrs.get(label=label)
                 ]
             for attr in attrs:
-                value = attr.value
+                value = attr.to_brat()
 
                 if isinstance(value, bool) and not value:
                     # in brat 'False' means the attributes does not exist
@@ -462,7 +445,7 @@ class BratOutputConverter(OutputConverter):
                     for a in medkit_relation.attrs.get(label=label)
                 ]
             for attr in attrs:
-                value = attr.value
+                value = attr.to_brat()
 
                 if isinstance(value, bool) and not value:
                     continue
@@ -486,16 +469,48 @@ class BratOutputConverter(OutputConverter):
     @staticmethod
     def _ensure_text_and_spans(
         segment: Segment, raw_text: str
-    ) -> Tuple[str, List[Span]]:
-        """Ensure consistency between `raw_text` and `segment.text`"""
-        # normalize and extract from raw_text
+    ) -> Tuple[str, List[Tuple[int, int]]]:
+        """Ensure consistency between the segment and the raw text.
+        The text of a BRAT annotation can't contain multiple white spaces (including a newline character).
+        This method clean the text of the fragments and adjust its spans to point to the same
+        location in the raw text.
+
+        Parameters
+        ----------
+        segment:
+            Segment to ensure
+        raw_text:
+            Text of reference
+
+        Returns
+        -------
+        Tuple[str, List[Tuple[int, int]]]
+            A tuple with the text cleaned and its spans
+        """
+        pattern_to_clean = r"(\s*\n+\s*)"
         segment_spans = span_utils.normalize_spans(segment.spans)
-        text = "".join(raw_text[sp.start : sp.end] for sp in segment_spans)
-        # remove multiple whitespaces because they are not supported by Brat
-        pattern = r"[ \t](?P<blanks>\s{2,})"
-        ranges = [(match.span("blanks")) for match in re.finditer(pattern, text)]
-        text, spans = span_utils.remove(text, segment_spans, ranges)
-        return text, spans
+        texts_brat, spans_brat = [], []
+
+        for fragment in segment_spans:
+            text = raw_text[fragment.start : fragment.end]
+            offset = fragment.start
+            # remove leading spaces from text or multiple spaces
+            text_stripped, start_text, end_text = utils.strip(text, offset)
+            real_offset = offset + start_text
+
+            # create text and spans without blank regions
+            for match in re.finditer(pattern_to_clean, text_stripped):
+                end_fragment = start_text + match.start()
+                texts_brat.append(raw_text[start_text:end_fragment])
+                spans_brat.append((start_text, end_fragment))
+                start_text = match.end() + real_offset
+
+            # add last fragment
+            texts_brat.append(raw_text[start_text:end_text])
+            spans_brat.append((start_text, end_text))
+
+        text_brat = " ".join(texts_brat)
+        return text_brat, spans_brat
 
     def _convert_segment_to_brat(
         self, segment: Segment, nb_segment: int, raw_text: str
@@ -520,8 +535,7 @@ class BratOutputConverter(OutputConverter):
         brat_id = f"T{nb_segment}"
         # brat does not support spaces in labels
         type = segment.label.replace(" ", "_")
-        text, _spans = self._ensure_text_and_spans(segment, raw_text)
-        spans = tuple((span.start, span.end) for span in _spans)
+        text, spans = self._ensure_text_and_spans(segment, raw_text)
         return BratEntity(brat_id, type, spans, text)
 
     @staticmethod
