@@ -1,3 +1,8 @@
+"""
+This module needs extra-dependencies not installed as core dependencies of medkit.
+To install them, use `pip install medkit-lib[umls-coder-normalizer]`.
+"""
+
 __all__ = ["UMLSCoderNormalizer"]
 
 from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Union
@@ -15,7 +20,7 @@ from medkit.core.text import Entity
 import medkit.core.utils
 from medkit.text.ner.umls_norm_attribute import UMLSNormAttribute
 from medkit.text.ner.umls_utils import (
-    load_umls,
+    load_umls_entries,
     preprocess_term_to_match,
     guess_umls_version,
 )
@@ -111,7 +116,7 @@ class UMLSCoderNormalizer(Operation):
         lowercase:
             Whether to use lowercased versions of UMLS terms and input entities.
         normalize_unicode:
-            Whether to ASCII-only versions of UMLS terms and input entities
+            Whether to use ASCII-only versions of UMLS terms and input entities
             (non-ASCII chars replaced by closest ASCII chars).
         threshold:
             Minimum similarity threshold (between 0.0 and 1.0) between the embeddings
@@ -201,6 +206,9 @@ class UMLSCoderNormalizer(Operation):
             List of entities to add normalization attributes to
         """
 
+        if len(entities) == 0:
+            return
+
         # find best matches and assocatied score for all entities
         all_match_indices, all_match_scores = self._find_best_matches(entities)
 
@@ -315,7 +323,7 @@ class UMLSCoderNormalizer(Operation):
         ]
 
         # get iterator to all UMLS entries
-        entries_iter = load_umls(
+        entries_iter = load_umls_entries(
             self.umls_mrconso_file,
             languages=[self.language],
             show_progress=show_progress,
@@ -330,7 +338,13 @@ class UMLSCoderNormalizer(Operation):
         ):
             # get preprocess version of each term for matching
             terms_to_match = [
-                preprocess_term_to_match(e.term, self.lowercase, self.normalize_unicode)
+                preprocess_term_to_match(
+                    e.term,
+                    self.lowercase,
+                    self.normalize_unicode,
+                    clean_brackets=True,
+                    clean_dashes=True,
+                )
                 for e in chunk_entries
             ]
 
@@ -396,6 +410,16 @@ class _EmbeddingsPipeline(FeatureExtractionPipeline):
         self.summary_method = summary_method
         self.normalize = normalize
 
+    def _ensure_tensor_on_device(self, inputs, device):
+        """
+        Hack to force tensors to be kept on pipeline device. The base hugging
+        face pipeline tries to move the model outputs back to the cpu before
+        returning them but we want to keep them on the gpu if they are, because
+        we want to still be on the gpu when doing big similarity matrix multiplication
+        between entities embeddings and umls embeddings
+        """
+        return super()._ensure_tensor_on_device(inputs, self.device)
+
     def preprocess(self, inputs, truncation=True) -> Dict[str, torch.Tensor]:
         return self.tokenizer(
             inputs,
