@@ -1,3 +1,8 @@
+"""
+This package needs extra-dependencies not installed as core dependencies of medkit.
+To install them, use `pip install medkit-lib[spacy]`.
+"""
+
 __all__ = [
     "SpacyDocPipeline",
     "SpacyPipeline",
@@ -14,3 +19,6 @@ if not modules_are_available(["spacy"]):
 
 from .doc_pipeline import SpacyDocPipeline  # noqa: E402, F401
 from .pipeline import SpacyPipeline  # noqa: E402, F401
+
+if modules_are_available(["edsnlp"]):
+    __all__.append("edsnlp")
