@@ -4,7 +4,7 @@ __all__ = [
     "build_spacy_doc_from_medkit_segment",
 ]
 import warnings
-from typing import Dict, List, Optional, Tuple
+from typing import Callable, Dict, List, Optional, Tuple
 
 from spacy import Language
 from spacy.tokens import Doc
@@ -21,6 +21,7 @@ from medkit.core.text import (
     Span,
     span_utils,
 )
+from medkit.io._common import get_anns_by_type
 
 
 _ATTR_MEDKIT_ID = "medkit_id"
@@ -32,6 +33,9 @@ def extract_anns_and_attrs_from_spacy_doc(
     entities: Optional[List[str]] = None,
     span_groups: Optional[List[str]] = None,
     attrs: Optional[List[str]] = None,
+    attribute_factories: Optional[
+        Dict[str, Callable[[SpacySpan, str], Attribute]]
+    ] = None,
     rebuild_medkit_anns_and_attrs: bool = False,
 ) -> Tuple[List[Segment], Dict[str, List[Attribute]]]:
     """Given a spacy document, convert selected entities or spans into Segments.
@@ -52,6 +56,10 @@ def extract_anns_and_attrs_from_spacy_doc(
     attrs:
         Name of custom attributes to extract from the annotations that will be included.
         If `None` (default) all the custom attributes will be extracted
+    attribute_factories:
+        Mapping of factories in charge of converting spacy attributes to medkit
+        attributes. Factories will receive a spacy span and an attribute label
+        when called. The key in the mapping is the attribute label.
     rebuild_medkit_anns_and_attrs:
         If True the annotations and attributes with medkit ids will become
         new annotations/attributes with new ids.
@@ -71,6 +79,9 @@ def extract_anns_and_attrs_from_spacy_doc(
         Raises when the given medkit source and the spacy doc do not have the same medkit uid
     """
 
+    if attribute_factories is None:
+        attribute_factories = {}
+
     # extensions to indicate the medkit origin
     _define_default_extensions()
     spacy_doc_medkit_id = spacy_doc._.get(_ATTR_MEDKIT_ID)
@@ -111,11 +122,17 @@ def extract_anns_and_attrs_from_spacy_doc(
 
         # for each spacy extension having a value other than None,
         # a medkit Attribute is created
-        attributes = [
-            Attribute(label=attr, value=entity_spacy._.get(attr))
-            for attr in spacy_attrs
-            if entity_spacy._.get(attr) is not None
-        ]
+        attributes = []
+        for attr_label in spacy_attrs:
+            value = entity_spacy._.get(attr_label)
+            if value is None:
+                continue
+            factory = attribute_factories.get(attr_label)
+            if factory is not None:
+                attribute = factory(entity_spacy, attr_label)
+            else:
+                attribute = Attribute(attr_label, value)
+            attributes.append(attribute)
 
         if attributes:
             attributes_by_ann[medkit_id] = attributes
@@ -123,6 +140,12 @@ def extract_anns_and_attrs_from_spacy_doc(
     # convert spacy span groups
     for label, spans in spacy_spans.items():
         for span_spacy in spans:
+            # ignore spans that have a corresponding entity
+            # (some matchers, for instance in EDS-NLP create both an entity and
+            # a span for each match)
+            if span_spacy in spacy_entities:
+                continue
+
             medkit_id = span_spacy._.get(_ATTR_MEDKIT_ID)
 
             if medkit_id is None or rebuild_medkit_anns_and_attrs:
@@ -144,11 +167,17 @@ def extract_anns_and_attrs_from_spacy_doc(
 
             # for each spacy extension having a value other than None,
             # a medkit Attribute is created
-            attributes = [
-                Attribute(label=attr, value=span_spacy._.get(attr))
-                for attr in spacy_attrs
-                if span_spacy._.get(attr) is not None
-            ]
+            attributes = []
+            for attr_label in spacy_attrs:
+                value = span_spacy._.get(attr_label)
+                if value is None:
+                    continue
+                factory = attribute_factories.get(attr_label)
+                if factory is not None:
+                    attribute = factory(span_spacy, attr_label)
+                else:
+                    attribute = Attribute(attr_label, value)
+                attributes.append(attribute)
 
             if attributes:
                 attributes_by_ann[medkit_id] = attributes
@@ -193,25 +222,13 @@ def build_spacy_doc_from_medkit_doc(
 
     # get the raw text segment to transfer
     raw_segment = medkit_doc.raw_segment
-    annotations = medkit_doc.anns.get()
-
-    if labels_anns is not None:
-        # filter annotations by label
-        annotations = [ann for ann in annotations if ann.label in labels_anns]
-        if labels_anns and annotations == []:
-            # labels_anns were a list but none of the annotations
-            # had a label of interest
-            labels_str = ",".join(labels_anns)
-            warnings.warn(
-                f"No medkit annotations were included because none have '{labels_str}'"
-                " as label."
-            )
+    annotations = get_anns_by_type(medkit_doc, anns_labels=labels_anns)
 
     # create a spacy doc
     doc = build_spacy_doc_from_medkit_segment(
         nlp=nlp,
         segment=raw_segment,
-        annotations=annotations,
+        annotations=annotations["segments"] + annotations["entities"],
         attrs=attrs,
         include_medkit_info=include_medkit_info,
     )
@@ -436,12 +453,11 @@ def _segment_to_spacy_span(
 
     for label in attrs:
         for attr in medkit_segment.attrs.get(label=label):
-            if attr.value is None:
+            value = attr.to_spacy()
+            if value is None:
                 # in medkit having an attribute, indicates that the attribute exists
                 # for the given annotation, we force True as value
                 value = True
-            else:
-                value = attr.value
             # set attributes as extensions
             span._.set(attr.label, value)
             if include_medkit_info:
