@@ -1,3 +1,8 @@
+"""
+This module needs extra-dependencies not installed as core dependencies of medkit.
+To install them, use `pip install medkit-lib[hf-utils]`.
+"""
+
 __all__ = ["check_model_for_task_HF"]
 
 from pathlib import Path
